package com.dgtly.goods.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.goods.mapper.GoodsTypeAttributeMapper;
import com.dgtly.goods.domain.GoodsTypeAttribute;
import com.dgtly.goods.service.IGoodsTypeAttributeService;
import com.dgtly.common.core.text.Convert;

/**
 * 商品分类属性Service业务层处理
 * 
 * @author dgtly
 * @date 2020-02-13
 */
@Service
public class GoodsTypeAttributeServiceImpl implements IGoodsTypeAttributeService 
{
    @Autowired
    private GoodsTypeAttributeMapper goodsTypeAttributeMapper;

    /**
     * 查询商品分类属性
     * 
     * @param id 商品分类属性ID
     * @return 商品分类属性
     */
    @Override
    public GoodsTypeAttribute selectGoodsTypeAttributeById(Long id)
    {
        return goodsTypeAttributeMapper.selectGoodsTypeAttributeById(id);
    }

    /**
     * 查询商品分类属性列表
     * 
     * @param goodsTypeAttribute 商品分类属性
     * @return 商品分类属性
     */
    @Override
    public List<GoodsTypeAttribute> selectGoodsTypeAttributeList(GoodsTypeAttribute goodsTypeAttribute)
    {
        return goodsTypeAttributeMapper.selectGoodsTypeAttributeList(goodsTypeAttribute);
    }

    /**
     * 新增商品分类属性
     * 
     * @param goodsTypeAttribute 商品分类属性
     * @return 结果
     */
    @Override
    public int insertGoodsTypeAttribute(GoodsTypeAttribute goodsTypeAttribute)
    {
        goodsTypeAttribute.setCreateTime(DateUtils.getNowDate());
        return goodsTypeAttributeMapper.insertGoodsTypeAttribute(goodsTypeAttribute);
    }

    /**
     * 修改商品分类属性
     * 
     * @param goodsTypeAttribute 商品分类属性
     * @return 结果
     */
    @Override
    public int updateGoodsTypeAttribute(GoodsTypeAttribute goodsTypeAttribute)
    {
        goodsTypeAttribute.setUpdateTime(DateUtils.getNowDate());
        return goodsTypeAttributeMapper.updateGoodsTypeAttribute(goodsTypeAttribute);
    }

    /**
     * 删除商品分类属性对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteGoodsTypeAttributeByIds(String ids)
    {
        return goodsTypeAttributeMapper.deleteGoodsTypeAttributeByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除商品分类属性信息
     * 
     * @param id 商品分类属性ID
     * @return 结果
     */
    @Override
    public int deleteGoodsTypeAttributeById(Long id)
    {
        return goodsTypeAttributeMapper.deleteGoodsTypeAttributeById(id);
    }
}
